@@ -86,42 +86,43 @@ OC.L10N.register(
     "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "{imported}/{all} importálva, {errors} hiba, {duplicates} duplikátum kihagyva",
     "Audio alarm {time} before the event starts" : "Hangriasztás az esemény kezdete előtt ennyivel: {time}",
     "Pop-up {time} before the event starts" : "Felugró üzenet az esemény kezdete előtt ennyivel: {time}",
-    "Email {time} before the event starts" : "Email az esemény kezdete előtt ennyivel: {time}",
+    "Email {time} before the event starts" : "E-mail az esemény kezdete előtt ennyivel: {time}",
     "None {time} before the event starts" : "Nincs {time} idővel az esemény kezdete előtt",
     "{type} {time} before the event starts" : "{type} {time} idő múlva kezdődik az esemény",
     "Audio alarm {time} before the event ends" : "Hangriasztás az esemény vége előtt ennyivel: {time}",
     "Pop-up {time} before the event ends" : "Felugró üzenet az esemény vége előtt ennyivel: {time}",
-    "Email {time} before the event ends" : "Email az esemény vége előtt ennyivel: {time}",
+    "Email {time} before the event ends" : "E-mail az esemény vége előtt ennyivel: {time}",
     "None {time} before the event ends" : "Nincs {time} idővel az esemény vége előtt",
     "{type} {time} before the event ends" : "{type} {time} idő múlva végződik az esemény",
     "Audio alarm {time} after the event starts" : "Hangriasztás az esemény kezdete után ennyivel: {time}",
     "Pop-up {time} after the event starts" : "Felugró üzenet az esemény kezdete után ennyivel: {time}",
-    "Email {time} after the event starts" : "Email az esemény kezdete után ennyivel: {time}",
+    "Email {time} after the event starts" : "E-mail az esemény kezdete után ennyivel: {time}",
     "None {time} after the event starts" : "Nincs {time} idővel az esemény kezdése után",
     "{type} {time} after the event starts" : "{type} {time} esemény kezdete után",
     "Audio alarm {time} after the event ends" : "Hangriasztás az esemény vége után ennyivel: {time}",
     "Pop-up {time} after the event ends" : "Felugró üzenet az esemény vége után ennyivel: {time}",
-    "Email {time} after the event ends" : "Email az esemény vége után ennyivel: {time}",
+    "Email {time} after the event ends" : "E-mail az esemény vége után ennyivel: {time}",
     "None {time} after the event ends" : "Nincs {time} idővel az esemény után",
     "{type} {time} after the event ends" : "{type} {time} esemény vége után",
     "Audio alarm at the event's start" : "Hangriasztás az esemény kezdetekor",
     "Pop-up at the event's start" : "Felugró üzenet az esemény kezdetekor",
-    "Email at the event's start" : "Email az esemény kezdetekor",
+    "Email at the event's start" : "E-mail az esemény kezdetekor",
     "None at the event's start" : "Nincs az esemény kezdetén",
     "{type} at the event's start" : "{type} az esemény kezdetekor",
     "Audio alarm at the event's end" : "Hangriasztás az esemény végén",
     "Pop-up at the event's end" : "Felugró üzenet az esemény végén",
-    "Email at the event's end" : "Email az esemény végén",
+    "Email at the event's end" : "E-mail az esemény végén",
     "None at the event's end" : "Nincs az esemény végén",
     "{type} at the event's end" : "{type} az esemény végén",
     "Audio alarm at {time}" : "Hangriasztás ekkor: {time}",
     "Pop-up at {time}" : "Felugró üzenet ekkor: {time}",
-    "Email at {time}" : "Email ekkor: {time}",
+    "Email at {time}" : "E-mail ekkor: {time}",
     "None at {time}" : "Semmi ekkor {time}",
     "{type} at {time}" : "{type} ekkor: {time}",
     "{calendar} shared by {owner}" : "{calendar} megosztója: {owner}",
     "Please enter a valid WebCal-URL" : "Kérlek adj meg egy érvényes WebCal-URL-t",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Komoly hiba van a webcal proxynál. További információkért kérlek vedd fel a kapcsolatot a rendszergazdával.",
+    "A Calendar app for Nextcloud" : "Naptár alkalmazás a Nextcloud-hoz",
     "Title of the Event" : "Az esemény címe",
     "Starts" : "Kezdődik",
     "Ends" : "Véget ér",
@@ -173,10 +174,10 @@ OC.L10N.register(
     "Absolute" : "Abszolút",
     "Repeat" : "Ismétlés",
     "times every" : "mindennyiszer",
-    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Az email emlékeztetők még nincsenek implementálva a CalDAV szerverbe, ezért semmi nem lesz elküldve.",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Az e-mail emlékeztetők még nincsenek implementálva a CalDAV szerverbe, ezért semmi nem lesz elküldve.",
     "Add" : "Hozzáadás",
     "Email address of attendee" : "Résztvevők e-mail címe",
-    "Please add your email address in the personal settings in order to add attendees." : "Kérem adja meg az email címét a személyes beállításokban, hogy résztvevőket tudjon hozzáadni.",
+    "Please add your email address in the personal settings in order to add attendees." : "Kérem adja meg az e-mail címét a személyes beállításokban, hogy résztvevőket tudjon hozzáadni.",
     "from" : "feladó",
     "to" : "címzett",
     "This event's repeating rule is not supported yet." : "Ennek az eseménynek az ismétlődő szabálya még nem támogatott.",
@@ -197,10 +198,10 @@ OC.L10N.register(
     "Embed" : "Beágyazott",
     "Iframe to integrate" : "Beépítendő iframe",
     "Publish URL" : "Közzétételi URL",
-    "Settings & import" : "Beállítások és Import",
+    "Settings & import" : "Beállítások és Importálás",
     "Import calendar" : "Naptár importálása",
     "No Calendars selected for import" : "Nincs importálásra kiválasztott naptár",
-    "Skip simple event editor" : "Váltás az egyszerű esemény szerkesztőre",
+    "Skip simple event editor" : "Az egyszerű eseményszerkesztő kihagyása",
     "Show week numbers" : "Hetek számának megjelenítése",
     "Timezone" : "Időzóna",
     "Primary CalDAV address" : "Elsődleges CalDAV cím",
