@@ -30,6 +30,7 @@ OC.L10N.register(
     "Share Calendar" : "カレンダーを共有する",
     "Shared" : "共有中",
     "WebDAV address for subscriptions" : "サブスクリプションのWebDAVアドレス",
+    "Email sent." : "メールを送信しました。",
     "group" : "グループ",
     "Details" : "詳細",
     "Attendees" : "参加者",
@@ -38,7 +39,7 @@ OC.L10N.register(
     "When shared show full event" : "共有時にすべてのイベントを表示",
     "When shared show only busy" : "共有時に実行中のみを表示",
     "When shared hide this event" : "共有時にこのイベントを隠す",
-    "Confirmed" : "確認されました",
+    "Confirmed" : "確認済み",
     "Tentative" : "暫定的",
     "Cancelled" : "キャンセル済",
     "Please add a title." : "タイトルをつけてください。",
@@ -62,7 +63,7 @@ OC.L10N.register(
     "2 hours before" : "2時間前",
     "Custom" : "カスタム",
     "Audio" : "オーディオ",
-    "Email" : "電子メール",
+    "Email" : "メール",
     "Pop-up" : "ポップアップ",
     "sec" : "秒",
     "min" : "最低",
@@ -78,8 +79,11 @@ OC.L10N.register(
     "{type} {time} before the event ends" : "イベント終了の{type} {time} 前",
     "{type} {time} after the event starts" : "イベント開始の{type} {time} 後",
     "{type} {time} after the event ends" : "イベント終了の{type} {time} 後",
+    "Email at the event's start" : "イベント開始時にメールを送信する",
     "{type} at the event's start" : "{type} イベント開始時",
+    "Email at the event's end" : "イベント終了時にメールを送信する",
     "{type} at the event's end" : "{type} イベント終了時",
+    "Email at {time}" : "{time} にメールを送信",
     "{type} at {time}" : "{type} {time} 時",
     "{calendar} shared by {owner}" : "{owner} が共有中の{calendar} ",
     "Please enter a valid WebCal-URL" : "有効なWebCal-URLを入力してください",
@@ -113,11 +117,10 @@ OC.L10N.register(
     "Link" : "リンク",
     "iCal link" : "iCal リンク",
     "Download" : "ダウンロード",
-    "Share with users or groups" : "ユーザーもしくはグループと共有",
+    "Share with users or groups" : "ユーザーまたはグループと共有",
     "can edit" : "編集を許可",
     "Share link" : "URLで共有",
     "Public access" : "パブリックアクセス",
-    "Email link to person" : "電子メールリンク",
     "Send" : "送信",
     "New Calendar" : "新しいカレンダーを作成",
     "Name" : "名前",
@@ -136,7 +139,7 @@ OC.L10N.register(
     "Repeat" : "繰り返し",
     "times every" : "繰り返し",
     "Add" : "追加",
-    "Email address of attendee" : "参加者の電子メールアドレス",
+    "Email address of attendee" : "参加者のメールアドレス",
     "Please add your email address in the personal settings in order to add attendees." : "出席者に追加するにはアカウント設定でメールアドレスを追加してください",
     "from" : "差出人",
     "to" : "宛先",
@@ -147,7 +150,7 @@ OC.L10N.register(
     "end repeat ..." : "繰り返しの終わり...",
     "times" : "回数",
     "Import Calendars" : "カレンダーのインポート",
-    "Import canceled" : "インポートはキャンセルされました",
+    "Import canceled" : "インポートをキャンセルしました",
     "Analyzing calendar" : "カレンダーの解析中",
     "The file contains objects incompatible with the selected calendar" : "指定したカレンダーに互換性のない情報がファイルに含まれています",
     "New calendar" : "新しいカレンダー",
@@ -163,7 +166,6 @@ OC.L10N.register(
     "Skip simple event editor" : "シンプルイベントエディタをスキップ",
     "Show week numbers" : "週番号を表示する",
     "Primary CalDAV address" : "一番目の CalDAV アドレス",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV アドレス",
     "Subscribe" : "購読"
 },
 "nplurals=1; plural=0;");
